%define anolis_release 1
%global _hardened_build 1

Summary:        Random number generator related utilities
Name:           rng-tools
Version:        6.17
Release:        %{anolis_release}%{?dist}
License:        GPLv2+
URL:            https://github.com/nhorman/rng-tools
Source0: 	https://github.com/nhorman/rng-tools/archive/v%{version}/%{name}-%{version}.tar.gz
Source1:        rngd.service
Source2:        rngd.sysconfig

BuildRequires: gcc make binutils
BuildRequires: gettext
BuildRequires: systemd systemd-rpm-macros
BuildRequires: autoconf automake
BuildRequires: libgcrypt-devel libcurl-devel
BuildRequires: libxml2-devel openssl-devel
BuildRequires: jitterentropy-devel
BuildRequires: jansson-devel
BuildRequires: libcap-devel

Requires(post): systemd
Requires(preun): systemd
Requires(postun): systemd

# This ensures that the selinux-policy package and all its dependencies
# are not pulled into containers and other systems that do not use SELinux.
Requires: (selinux-policy >= 36.5 if selinux-policy)

Patch0001: 1-rt-comment-out-have-aesni.patch


# some patches to Add Intel CET IBT instrumentation to assembly code
Patch0002: 0002-Add-Intel-CET-IBT-instrumentation-to-assembly-code.patch
Patch0003: 0003-Refactor-xread_tpm-code.patch
Patch0004: 0004-Check-return-value-of-sysconf-calls.patch
Patch0005: 0005-Add-error-handling-to-jitter-read-and-pipe-write-loops.patch
Patch0006: 0006-Add-a-Null-check-for-calloc-return-values.patch
Patch0007: 0007-brush-up-test-scripts.patch

%description
Hardware random number generation tools.

%package doc
Summary:        Documentation files for %{name}
Requires:       %{name} = %{version}-%{release}
BuildArch:      noarch

%description    doc
The %{name}-doc package contains documentation files for %{name}.

%prep
%autosetup -p1

%build
export CFLAGS="$CFLAGS  -DJENT_CONF_ENABLE_INTERNAL_TIMER"
./autogen.sh

# a dirty hack so libdarn_impl_a_CFLAGS overrides common CFLAGS
sed -i -e 's/$(libdarn_impl_a_CFLAGS) $(CFLAGS)/$(CFLAGS) $(libdarn_impl_a_CFLAGS)/' Makefile.in

%configure --without-pkcs11 --without-rtlsdr
%make_build

%install
%make_install

# install systemd unit file
install -Dt %{buildroot}%{_unitdir} -m0644 %{SOURCE1}
# install sysconfig file
install -D %{SOURCE2} -m0644 %{buildroot}%{_sysconfdir}/sysconfig/rngd

%generate_compatibility_deps

%post
%systemd_post rngd.service

%preun
%systemd_preun rngd.service

%postun
%systemd_postun_with_restart rngd.service

%files
%license COPYING
%{_bindir}/rngtest
%{_sbindir}/rngd
%{_bindir}/randstat
%{_mandir}/man1/rngtest.1.*
%{_mandir}/man8/rngd.8.*
%attr(0644,root,root)    %{_unitdir}/rngd.service
%config(noreplace) %attr(0644,root,root)    %{_sysconfdir}/sysconfig/rngd
%dir %{abidir}
%{abidir}/*-option.list

%files doc
%doc AUTHORS README

%changelog
* Wed Mar 19 2025 happy_orange <songnannan@linux.alibaba.com> - 6.17-1
- update to 6.17
- backport some patches from upstream to add intel CET IBT instrumentation

* Tue Apr 30 2024 Zhao Hang <wb-zh951434@alibaba-inc.com> - 6.16-3
- Rebuild for Anolis 23

* Mon Mar 27 2023 mgb01105731 <mgb01105731@alibaba-inc.com> - 6.16-2
- Del Specific Fields

* Thu Mar 23 2023 Chunmei Xu <xuchunmei@linux.alibaba.com> - 6.16-1
- update to 6.16

* Wed Dec 28 2022 Shawn Wang <shawnwang@linux.alibaba.com> - 6.15-3
- update spec file

* Mon Jun 13 2022 Chunmei Xu <xuchunmei@linux.alibaba.com> - 6.15-2
- fix build failed with new jitterentropy

* Wed Mar 09 2022 Renbo <rb01097748@alibaba-inc.com> - 6.15-1
- Init for Anolis OS 23
